@@ -22,8 +22,7 @@
 #define KPK_UPDATE_DETAILS_H
 
 #include <QPackageKit>
-
-#include "KpkPackageModel.h"
+#include <KPixmapSequenceOverlayPainter>
 
 #include "ui_KpkUpdateDetails.h"
 
@@ -33,17 +32,28 @@ class KpkUpdateDetails : public QWidget, Ui::KpkUpdateDetails
 {
 Q_OBJECT
 public:
-    explicit KpkUpdateDetails(PackageKit::Package *package, QWidget *parent = 0);
+    explicit KpkUpdateDetails(QWidget *parent = 0);
     ~KpkUpdateDetails();
 
+    void setPackage(const QString &packageId, Enum::Info updateInfo);
+    void hide();
+
 private slots:
     void updateDetail(PackageKit::Client::UpdateInfo info);
-    void updateDetailFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
+    void updateDetailFinished();
+    void display();
 
 private:
-    Package::State state;
-
     QString getLinkList(const QString &links) const;
+
+    bool m_show;
+    QString m_packageId;
+    Transaction *m_transaction;
+    QString m_currentDescription;
+    Enum::Info m_updateInfo;
+    KPixmapSequenceOverlayPainter *m_busySeq;
+    QPropertyAnimation *m_fadeDetails;
+    QParallelAnimationGroup *m_expandPanel;
 };
 
 #endif
