@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Daniel Nicoletti                                *
+ *   Copyright (C) 2008-2010 by Daniel Nicoletti                           *
  *   dantti85-pk@yahoo.com.br                                              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,24 +22,20 @@
 #define KPK_REVIEW_CHANGES_H
 
 #include <KDialog>
-#include <KProgressDialog>
-
-#include <KpkDelegate.h>
-#include <KpkTransaction.h>
-#include "KpkPackageModel.h"
-#include "KpkSimulateModel.h"
 
 #include <QPackageKit>
+#include "KpkTransaction.h"
 
 using namespace PackageKit;
 
 class KpkReviewChangesPrivate;
-
 class KDE_EXPORT KpkReviewChanges : public KDialog
 {
     Q_OBJECT
 public:
-    explicit KpkReviewChanges(const QList<Package*> &packages, QWidget *parent = 0);
+    explicit KpkReviewChanges(const QList<QSharedPointer<PackageKit::Package> > &packages,
+                              QWidget *parent = 0,
+                              uint parentWId = 0);
     ~KpkReviewChanges();
 
     enum OperationMode {
@@ -52,58 +48,32 @@ public:
     };
     Q_DECLARE_FLAGS(OperationModes, OperationMode)
 
-    void setTitle(const QString &title);
-    void setText(const QString &text);
-
+    void setMessage(const QString &msg);
     int exec(OperationModes flags = 0);
 
+signals:
+    void successfullyInstalled();
+    void successfullyRemoved();
+
 private slots:
-    void remFinished(KpkTransaction::ExitStatus);
-    void addFinished(KpkTransaction::ExitStatus);
+    void installPackages();
+    void removePackages(bool allow_deps = true);
 
-    void simRemFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
-    void simInstFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
-
-    void ensureRemoveFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
-    void ensureInstallFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
+    void transactionFinished(KpkTransaction::ExitStatus status);
 
     void doAction();
     void checkChanged();
 
 private:
-    void installPackages();
-    void removePackages(bool allow_deps = true);
+    void taskDone(PackageKit::Enum::Role role);
 
-    void installDone();
-    void removeDone();
-
-    KpkReviewChangesPrivate *d;
-    KpkPackageModel *m_pkgModelMain;
-    KpkSimulateModel *m_installPkgModel, *m_removePkgModel;
-    KpkDelegate *m_pkgDelegate;
-
-    Client *m_client;
-    Transaction *m_transactionReq;
-    Transaction *m_transactionDep;
-    QTimer m_notifyT;
-    int m_viewWidth;
-
-    void updateColumnsWidth(bool force = false);
     void checkTask();
 
-    QList<Package*> m_remPackages;
-    QList<Package*> m_addPackages;
-    QList<Package*> m_reqDepPackages;
-
-    Client::Actions m_actions;
+    KpkReviewChangesPrivate *d;
     OperationModes m_flags;
 
 protected slots:
     virtual void slotButtonClicked(int button);
-
-protected:
-    virtual void resizeEvent(QResizeEvent *event);
-    virtual bool event(QEvent *event);
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KpkReviewChanges::OperationModes)
